google_maps_flutter_android library

Classes

GoogleMapsFlutterAndroid
An implementation of GoogleMapsFlutterPlatform for Android.
HostMapMessageHandler
Callback handler for map events from the platform host.

Enums

AndroidMapRenderer
The possible android map renderer types that can be requested from the native Google Maps SDK.

Functions

platformJointTypeFromJointType(JointType jointType) → PlatformJointType
Converts platform interface's JointType to Pigeon's PlatformJointType.
platformMarkerCollisionBehaviorFromMarker(Marker marker) → PlatformMarkerCollisionBehavior
Converts a Marker's collision behavior to Pigeon's PlatformMarkerCollisionBehavior.
platformPatternItemFromPatternItem(PatternItem item) → PlatformPatternItem
Converts a PatternItem to Pigeon's PlatformPatternItem for PlatformPolyline pattern member.

Exceptions / Errors

AndroidMapRendererException
Thrown to indicate that a platform interaction failed to initialize renderer.
UnknownMapIDError
Error thrown when an unknown map ID is provided to a method channel API.